@@ -1,7 +1,4 @@
-__version__ = '0.1.0'
+__version__ = "0.1.0"
 from aithermal.frame_runner import *
 import aithermal.utils as utils
 from aithermal.utils import *
-from aithermal.utils import topic_directories, method_directories
-
-
